@@ -54,9 +54,9 @@ from syncthing_gtk.uibuilder import UIBuilder
 log = logging.getLogger("App")
 
 # Internal version used by updater (if enabled)
-INTERNAL_VERSION = "v0.9.4.5"
+INTERNAL_VERSION = "v0.10.0"
 # Minimal Syncthing version supported by App
-MIN_ST_VERSION = "0.14.50"
+MIN_ST_VERSION = "2.0.0"
 
 COLOR_DEVICE = "#707070"  # Dark-gray
 COLOR_DEVICE_SYNCING = "#2A89C8"  # Blue
@@ -106,7 +106,7 @@ class App(Gtk.Application, TimerManager):
     after start.
     """
 
-    def __init__(self, gladepath="/usr/share/syncthing-gtk", iconpath="/usr/share/syncthing-gtk/icons"):
+    def __init__(self, uipath="/usr/share/syncthing-gtk/ui", iconpath="/usr/share/syncthing-gtk/icons"):
         Gtk.Application.__init__(
             self, application_id="me.kozec.syncthingtk", flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE
         )
@@ -114,7 +114,7 @@ class App(Gtk.Application, TimerManager):
         # Setup Gtk.Application
         self.setup_commandline()
         # Set variables
-        self.gladepath = gladepath
+        self.uipath = uipath
         self.iconpath = iconpath
         self.builder = None
         self.rightclick_box = None
@@ -206,7 +206,7 @@ class App(Gtk.Application, TimerManager):
         elif is_option("about"):
             from syncthing_gtk.aboutdialog import AboutDialog
 
-            ad = AboutDialog(self, self.gladepath, self.iconpath)
+            ad = AboutDialog(self, self.uipath, self.iconpath)
             ad.run([])
             sys.exit(0)
 
@@ -354,10 +354,10 @@ class App(Gtk.Application, TimerManager):
             self.builder.enable_condition("is_gnome")
         # Fix icon path
         self.builder.replace_icon_path("icons/", self.iconpath)
-        # Load glade file
-        self.builder.add_from_file(os.path.join(self.gladepath, "app.glade"))
+        # Load ui file
+        self.builder.add_from_file(os.path.join(self.uipath, "app.ui"))
         self.builder.connect_signals(self)
-        # Dunno how to do this from glade
+        # Dunno how to do this from ui-file
         if self.use_headerbar and IS_GNOME:
             self.set_app_menu(self["app-menu"])
 
@@ -373,13 +373,6 @@ class App(Gtk.Application, TimerManager):
                 submenu.add(menuitem)
             self[limitmenu].show_all()
 
-        if not self["edit-menu-icon"] is None:
-            if not Gtk.IconTheme.get_default().has_icon(self["edit-menu-icon"].get_icon_name()[0]):
-                # If requested icon is not found in default theme, replace it with emblem-system-symbolic
-                self["edit-menu-icon"].set_from_icon_name(
-                    "emblem-system-symbolic", self["edit-menu-icon"].get_icon_name()[1]
-                )
-
         # Set window title in way that even Gnome can understand
         icon = os.path.join(self.iconpath, "syncthing-gtk.png")
         self["window"].set_title(_("Syncthing-GTK"))
@@ -471,7 +464,7 @@ class App(Gtk.Application, TimerManager):
     def show_wizard(self):
         from syncthing_gtk.wizard import Wizard
 
-        self.wizard = Wizard(self.gladepath, self.iconpath, self.config)
+        self.wizard = Wizard(self.uipath, self.iconpath, self.config)
         self.wizard.connect("cancel", self.cb_wizard_finished)
         self.wizard.connect("close", self.cb_wizard_finished)
         self.wizard.show()
@@ -898,7 +891,7 @@ class App(Gtk.Application, TimerManager):
             # This one needs special treatment because remote port changes
             # every time when this is reported.
             id = re.search("to ([-0-9A-Za-z]+)", message)
-            version = re.search("protocol \(([^\)]+)\)", message)
+            version = re.search("protocol \\(([^\\)]+)\\)", message)
             if not id or not version:
                 # Invalid format
                 return
@@ -1815,7 +1808,7 @@ class App(Gtk.Application, TimerManager):
     def cb_about(self, *a):
         from syncthing_gtk.aboutdialog import AboutDialog
 
-        AboutDialog(self, self.gladepath, self.iconpath).show(self["window"])
+        AboutDialog(self, self.uipath, self.iconpath).show(self["window"])
 
     def cb_delete_event(self, *e):
         # Hide main window
