@@ -2,7 +2,7 @@
 """
 Syncthing-GTK - 1st run wizard
 
-Basically runs Syncthing daemon with -generate option and setups some
+Basically runs Syncthing daemon with generate option and setups some
 values afterwards.
 """
 
@@ -33,14 +33,14 @@ MAX_PORT = 8100
 
 
 class Wizard(Gtk.Assistant):
-    def __init__(self, gladepath="/usr/share/syncthing-gtk", iconpath="/usr/share/syncthing-gtk/icons", config=None):
+    def __init__(self, uipath="/usr/share/syncthing-gtk", iconpath="/usr/share/syncthing-gtk/icons", config=None):
         # Init
         Gtk.Assistant.__init__(self)
         if config is not None:
             self.config = config
         else:
             self.config = Configuration()
-        self.gladepath = gladepath
+        self.uipath = uipath
         self.iconpath = iconpath
         self.syncthing_options = {}
         # Daemon and wizard output, maybe for error reports
@@ -381,7 +381,7 @@ class FindDaemonPage(Page):
                     log.info("Binary found in %s", bin_path)
                     if IS_WINDOWS:
                         bin_path = bin_path.replace("/", "\\")
-                    p = DaemonProcess([bin_path, "-version"])
+                    p = DaemonProcess([bin_path, "--version"])
                     p.connect("line", self.cb_process_output)
                     p.connect("exit", self.cb_process_exit)
                     p.connect("failed", self.cb_process_exit)
@@ -436,7 +436,7 @@ class FindDaemonPage(Page):
         else:
             # Found daemon binary too old to be usable.
             # Just ignore it and try to find better one.
-            log.info("Binary in %s is too old", bin_path)
+            log.info("Binary in %s is too old (%s)", bin_path, self.version_string)
             self.ignored_version = self.version_string
             GLib.idle_add(self.search)
 
@@ -528,7 +528,7 @@ class GenerateKeysPage(Page):
 
     def start_binary(self):
         """
-        Starts Syncthing binary with -generate parameter and waits until
+        Starts Syncthing binary with generate parameter and waits until
         key generation is finished
         """
         self.parent.output_line("syncthing-gtk: Configuration directory: '%s'" % (self.parent.st_configdir,))
@@ -538,10 +538,10 @@ class GenerateKeysPage(Page):
         except Exception as e:
             self.parent.output_line("syncthing-gtk: Failed to create configuration directory")
             self.parent.output_line("syncthing-gtk: %s" % (str(e),))
-        # Run syncthing -generate
+        # Run syncthing generate
         self.parent.output_line("syncthing-gtk: Syncthing configuration directory: %s" % (self.parent.st_configdir,))
         self.process = DaemonProcess(
-            [self.parent.config["syncthing_binary"], "-generate=%s" % self.parent.st_configdir]
+            [self.parent.config["syncthing_binary"], "generate", "--home", self.parent.st_configdir]
         )
         self.process.connect("line", lambda proc, line: self.parent.output_line(line))
         self.process.connect("exit", self.cb_daemon_exit)
